@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 # Version.
-our $VERSION = 0.23;
+our $VERSION = 0.24;
 
 1;
 
@@ -32,10 +32,12 @@ L<Map::Tube::Graph>,
 L<Map::Tube::GraphViz>,
 L<Map::Tube::Plugin::FuzzyFind>,
 L<Map::Tube::Plugin::Graph>,
+L<Map::Tube::Text::Shortest>,
 L<Map::Tube::Text::Table>,
 L<Test::Map::Tube>,
 
 L<Map::Tube::Barcelona>,
+L<Map::Tube::Beijing>,
 L<Map::Tube::Berlin>,
 L<Map::Tube::Bucharest>,
 L<Map::Tube::Budapest>,
@@ -82,6 +84,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.23
+0.24
 
 =cut
